# ExternalAPIWaybillTransportCostsWeightsToUse

The weights used to calculate the transport cost.  * `accepted_weights` - Accepted weights * `dispatched_weights` - Dispatched weights

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from openapi_client.models.external_api_waybill_transport_costs_weights_to_use import ExternalAPIWaybillTransportCostsWeightsToUse

# TODO update the JSON string below
json = "{}"
# create an instance of ExternalAPIWaybillTransportCostsWeightsToUse from a JSON string
external_api_waybill_transport_costs_weights_to_use_instance = ExternalAPIWaybillTransportCostsWeightsToUse.from_json(json)
# print the JSON string representation of the object
print(ExternalAPIWaybillTransportCostsWeightsToUse.to_json())

# convert the object into a dict
external_api_waybill_transport_costs_weights_to_use_dict = external_api_waybill_transport_costs_weights_to_use_instance.to_dict()
# create an instance of ExternalAPIWaybillTransportCostsWeightsToUse from a dict
external_api_waybill_transport_costs_weights_to_use_from_dict = ExternalAPIWaybillTransportCostsWeightsToUse.from_dict(external_api_waybill_transport_costs_weights_to_use_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


